/*  CCP CAN Stack for SocketCAN
    Copyright (C) 2015 Andreas Stewering-Bone

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>. */

/**
 * @file cs_ccp_codes.h
 * @author Andreas Stewering-Bone
 * @date 5 June 2015
 * @brief File containing several defined for the  CCP API.
 *
 * This file contain several defines for the CCP low level API.
 */

#ifndef CS_CCP_CODES_H
#define CS_CCP_CODES_H

#include "cs_defines.h"

/** \def CS_CCP_VERSION_MAJOR
    Major Version of CCP stack
*/
#define CS_CCP_VERSION_MAJOR 2

/** \def CS_CCP_VERSION_MINOR
    Minor Version of CCP stack
*/
#define CS_CCP_VERSION_MINOR 1

/** \def CS_CCP_VERSION
    Get version word from major minor version
*/
#define CS_CCP_VERSION(a, b) (((a) << 8) + (b))

/** \def CS_CCP_VERSION_MAGIC
    CCP interface version word.
 */
#define CS_CCP_VERSION_MAGIC CS_CCP_VERSION(CS_CCP_VERSION_MAJOR, CS_CCP_VERSION_MINOR)

/** \def CS_CCP_CHECKVERSION
    Check CCP stack compatibility
    \retval 0 if stack is compatible
    \retval 1 if stack is incompatible
*/
#define CS_CCP_CHECKVERSION ((CS_CCP_VERSION_MAGIC == cs_ccp_getversion())?0:1)

#define CCP_EVENT_MAX CS_CHARBUF
#define CCP_CMD_BUF 0xFF
#define CCP_ERR_BUF 0xFF
#define CCP_DATALENGTH 8
#define CCP_DAQMAX 8
#define CCP_ODTENTRYMAX 7
#define CCP_ODTMAXSIZE 7
#define CCP_EXCHANGEID_SIZE 0x100

/*Table of Return Codes (Packet identifier)*/
/** \def CCP_DTO_CRM
    CRM Command return message  
*/
#define CCP_DTO_CRM 0xFF 
/** \def CCP_DTO_EV
    Event message identifier  
*/
#define CCP_DTO_EV 0xFE 


/*Table of Cmd definitions*/
/** \def CCP_CMD_NONE
    No cmd
*/
#define CCP_CMD_NONE 0x00
/** \def CCP_CMD_CONNECT
    Connect
*/
#define CCP_CMD_CONNECT 0x01
/** \def CCP_CMD_GETCCPVERSION
    Get CCP version
*/
#define CCP_CMD_CCPVERSION 0x1B
/** \def CCP_CMD_EXCHANGE_ID
    Exchange ID
*/
#define CCP_CMD_EXCHANGE_ID 0x17
/** \def CCP_CMD_GETSEED
    Exchange ID
*/
#define CCP_CMD_GETSEED 0x12
/** \def CCP_CMD_UNLOCK
    Unlock
*/
#define CCP_CMD_UNLOCK 0x13
/** \def CCP_CMD_SETMTA
    Set MTA address
*/
#define CCP_CMD_SETMTA 0x02
/** \def CCP_CMD_DNLOAD
    Download
*/
#define CCP_CMD_DNLOAD 0x03
/** \def CCP_CMD_DNLOAD6
    Download 6 Bytes
*/
#define CCP_CMD_DNLOAD6 0x23
/** \def CCP_CMD_UPLOAD
    Upload
*/
#define CCP_CMD_UPLOAD 0x04
/** \def CCP_CMD_SHORTUP
    Short upload
*/
#define CCP_CMD_SHORTUP 0x0F
/** \def CCP_CMD_SELECTCALPAGE
    Select calibration page
*/
#define CCP_CMD_SELECTCALPAGE 0x11
/** \def CCP_CMD_GETDAQSIZE
    Get DAQ size
*/
#define CCP_CMD_GETDAQSIZE 0x14
/** \def CCP_CMD_SETDAQPTR
    Set DAQ pointer
*/
#define CCP_CMD_SETDAQPTR 0x15
/** \def CCP_CMD_WRITEDAQ
    Write DAQ
*/
#define CCP_CMD_WRITEDAQ 0x16
/** \def CCP_CMD_STARTSTOP
    Start/Stop DAQ Transmission
*/
#define CCP_CMD_STARTSTOP 0x06
/** \def CCP_CMD_DISCONNECT
    Disconnect
*/
#define CCP_CMD_DISCONNECT 0x07
/** \def CCP_CMD_SETSSTATUS
    Set slave status
*/
#define CCP_CMD_SETSSTATUS 0x0C
/** \def CCP_CMD_GETSSTATUS
    Get slave status
*/
#define CCP_CMD_GETSSTATUS 0x0D
/** \def CCP_CMD_BUILDCHKSUM
    Build checksum
*/
#define CCP_CMD_BUILDCHKSUM 0x0E
/** \def CCP_CMD_CLEARMEMORY
    Clear memory
*/
#define CCP_CMD_CLEARMEMORY 0x10
/** \def CCP_CMD_PROGRAMM
    Programm
*/
#define CCP_CMD_PROGRAMM 0x18
/** \def CCP_CMD_PROGRAMM6
    Programm 6 Byte
*/
#define CCP_CMD_PROGRAMM6 0x22
/** \def CCP_CMD_MOVE
    Move
*/
#define CCP_CMD_MOVE 0x19
/** \def CCP_CMD_TEST
    Test
*/
#define CCP_CMD_TEST 0x05
/** \def CCP_CMD_GETACTIVECALPAGE
    Get active calibration page
*/
#define CCP_CMD_GETACTIVECALPAGE 0x09
/** \def CCP_CMD_STARTSTOPALL
    Start/ Stop DAQ lists
*/
#define CCP_CMD_STARTSTOPALL 0x08
/** \def CCP_CMD_DIAGSERVICE
    Diagnostic service
*/
#define CCP_CMD_DIAGSERVICE 0x20
/** \def CCP_CMD_ACTIONSERVICE
    Action service
*/
#define CCP_CMD_ACTIONSERVICE 0x21

/*Resource mask*/
/**\def CCP_RESOURCE_CALIBRATION
   Mask Calibration
*/
#define  CCP_RESOURCE_CALIBRATION 0x01
/**\def CCP_RESOURCE_DAQ
   Mask DAQ
*/
#define  CCP_RESOURCE_DAQ 0x02
/**\def CCP_RESOURCE_PGM
   Mask Programming
*/
#define  CCP_RESOURCE_PGM 0x40

/*Stack Return Codes*/
/**\def CCP_RC_DAQOVERLOAD
   DAQ processor overload
*/
#define CCP_RC_DAQOVERLOAD 0x01 
/**\def CCP_RC_CMDBUSY
   Command processor busy
*/
#define CCP_RC_CMDBUSY 0x10 
/**\def CCP_RC_DAQBUSY
   DAQ processor busy
*/
#define CCP_RC_DAQBUSY 0x11 
/**\def CCP_RC_INTERNALTIMEOUT
   Internal timeout
*/
#define CCP_RC_INTERNALTIMEOUT 0x12
/**\def CCP_RC_KEYREQUEST
   Key request
*/
#define CCP_RC_KEYREQUEST 0x18 
/**\def CCP_RC_SESSIONSTATUS
   Session status request
*/
#define CCP_RC_SESSIONSTATUS 0x19 
/**\def CCP_RC_COLDRESTART
   Cold restart request
*/
#define CCP_RC_COLDRESTART 0x20
/**\def CCP_RC_CALINIT
   CAL list initialize request
*/
#define CCP_RC_CALINIT 0x21
/**\def CCP_RC_DAQINIT
   DAQ list initialize request
*/
#define CCP_RC_DAQINIT 0x22
/**\def CCP_RC_CODEUPDATE
   Code update request
*/
#define CCP_RC_CODEUPDATE 0x23
/**\def CCP_RC_CMDUNKNOWN
   Unknown cmd
*/
#define CCP_RC_CMDUNKNOWN 0x30
/**\def CCP_RC_CMDSYNTAX
   Cmd syntax
*/
#define CCP_RC_CMDSYNTAX 0x31
/**\def CCP_RC_PARAMETER
   Parameter out of range
*/
#define CCP_RC_PARAMETER 0x32
/**\def CCP_RC_ACCESSDENIED
   Access denied
*/
#define CCP_RC_ACCESSDENIED 0x33
/**\def CCP_RC_OVERLOAD
   Overload
*/
#define CCP_RC_OVERLOAD 0x34
/**\def CCP_RC_ACCESSLOCKED
   Access locked
*/
#define CCP_RC_ACCESSLOCKED 0x35
/**\def CCP_RC_NOTAVAILABLE
   Function not available
*/
#define CCP_RC_NOTAVAILABLE 0x36

/*Session Status Bytes*/
/** \def CCP_SSTATUS_CALINIT
    Calibration initialized
*/
#define CCP_SSTATUS_CALINIT 0x01
/** \def CCP_SSTATUS_DAQINIT
    DAQ lists initialized
*/
#define CCP_SSTATUS_DAQINIT 0x02
/** \def CCP_SSTATUS_DAQSAVE
    DAQ save
*/
#define CCP_SSTATUS_DAQSAVE 0x04
/** \def CCP_SSTATUS_CALSAVE
    Calibration save
*/
#define CCP_SSTATUS_CALSAVE 0x40
/** \def CCP_SSTATUS_RUN
    Run
*/
#define CCP_SSTATUS_RUN 0x80



/*Internal Error codes*/
/**\def CCP_ERROR_NOERROR
   No error
*/
#define CCP_ERROR_NOERROR 0x0
/**\def CCP_ERROR_CANIFACE
   CAN interface error
*/
#define CCP_ERROR_CANIFACE 0xA0
/**\def CCP_ERROR_SEND
   CCP send failure
*/
#define CCP_ERROR_SEND 0xA1
/**\def CCP_ERROR_TXFULL
   CCP send buffer full
*/
#define CCP_ERROR_TXFULL 0xA2
/**\def CCP_ERROR_RECVTIMEOUT
   CCP recv timeout
*/
#define CCP_ERROR_RECVTIMEOUT 0xA3
/**\def CCP_ERROR_RECV
   CCP recv failure
*/
#define CCP_ERROR_RECV 0xA4
/**\def CCP_ERROR_RECVINVALID
   CCP recv packet invalid
*/
#define CCP_ERROR_RECVINVALID 0xA5
/**\def CCP_ERROR_NOTSUPPORTEDAPI
   CMD is supported via API
*/
#define CCP_ERROR_NOTSUPPORTEDAPI 0xA6
/**\def CCP_ERROR_NOTSUPPORTEDSLAVE
   CMD is supported via Slave
*/
#define CCP_ERROR_NOTSUPPORTEDSLAVE 0xA7
/**\def CCP_ERROR_PARAMETER
   Invalid parameter
*/
#define CCP_ERROR_PARAMETER 0xA8
/**\def CCP_ERROR_MALLOC
   Malloc failure
*/
#define CCP_ERROR_MALLOC 0xA9
/**\def CCP_ERROR_DAQCONFIG
   DAQ config failure
*/
#define CCP_ERROR_DAQCONFIG 0xAA
/**\def CCP_ERROR_A2LSIGNAL
   Cannot find singal in A2L
*/
#define CCP_ERROR_A2LSIGNAL 0xAB
/**\def CCP_ERROR_CCPVERSION
   Incompatible CCP Version
*/
#define CCP_ERROR_CCPVERSION 0xAC

#endif
