/*  CCP CAN Stack for SocketCAN
    Copyright (C) 2015 Andreas Stewering-Bone

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>. */

/**
 * @file cs_ccp_decoder.h
 * @author Andreas Stewering-Bone
 * @date 30 June 2015
 * @brief File containing the CCP decoding API.
 *
 * This file contain the CCP decoding API. It is based on ASAM CCP specification.
 * The implementation is not complete and based on the Spec 2.1 version.
 */

#ifndef CS_CCP_DECODER_H
#define CS_CCP_DECODER_H

#include <inttypes.h>

#include "cs_ccp.h"

/** \struct cs_ccp_decoder_t
    Storage structure for CCP sniffer decoding
*/
typedef struct{
  cs_ccp_a2l_t ccpa2l;
  uint8_t master_cmd;
  uint8_t data_len;
}cs_ccp_decoder_t;

#ifdef __cplusplus
extern "C" {
#endif

  /** Init Structure
      \retval 1 Failure
      \retval 0 OK
  */
  int cs_ccp_decoder_open(
			  cs_ccp_decoder_t *data,              /**< Storage structure*/
			  char* filename,                      /**< A2L filename*/
			  char* project,                       /**< A2L project*/
			  char *module                         /**< A2L module*/
			  );

  /** Decode raw CAN frame, prints to STDOUT
      \retval 1 Failure
      \retval 0 OK
  */
  int cs_ccp_decoder_buffer(cs_ccp_decoder_t *data,           /**< Storage structure*/
			    double ts,                        /**< Timestamp*/
			    uint32_t canid,                   /**< CAN id*/
			    uint8_t * buffer,                 /**< Raw buffer*/
			    int len,                          /**< Raw buffer len*/
			    char *out,                        /**< Output buffer*/
			    int outlen                        /**< Output buffer length*/
			    );

  /** Close structure
      \retval 1 Failure
      \retval 0 OK
  */
  int cs_ccp_decoder_close(
		   cs_ccp_decoder_t *data           /**< Storage structure*/
		   );

#ifdef __cplusplus
}
#endif

#endif
