/*  Copyright (C) 2013 Andreas Stewering-Bone

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>. */
#ifndef CS_DEBUG_H
#define CS_DEBUG_H

#include <inttypes.h>
#include <stdarg.h>

/** \enum cs_debug_level_t
    CS debug level
*/
typedef enum{
  CS_DEBUG_LEVEL_READ = 0x00,     /**< Only read debug level*/
  CS_DEBUG_LEVEL_NONE = 0x01,     /**< No output*/
  CS_DEBUG_LEVEL_ERROR = 0x02,    /**< Error output*/
  CS_DEBUG_LEVEL_WARN = 0x04,     /**< Warning output*/
  CS_DEBUG_LEVEL_INFO = 0x08,     /**< Debugging output*/
  CS_DEBUG_LEVEL_DEBUG = 0x10,    /**< Debugging output*/
  CS_DEBUG_LEVEL_VERBOSE = 0x20   /**< Verbose output*/
}cs_debug_level_t;

/** \enum cs_debug_sub_t
    Debug Subsystems
    Keep in same oder than internal state array
*/
typedef enum{
  CS_DEBUG_SOCKETCAN = 0,        /**< SocketCAN layer*/
  CS_DEBUG_ISOTP,                /**< IsoTP layer*/
  CS_DEBUG_UDS,                  /**< UDS layer*/
  CS_DEBUG_CCP,                  /**< CCP layer*/
  CS_DEBUG_XCP,                  /**< XCP layer*/
  CS_DEBUG_SIGNAL,               /**< Signal layer*/
  CS_DEBUG_MESSAGE,              /**< Message layer*/
  CS_DEBUG_LIN,                  /**< LIN layer*/
  CS_DEBUG_LIN_BIT,              /**< LIN Bit layer*/
  CS_DEBUG_DBC,                  /**< DBC layer*/
  CS_DEBUG_SCHEDULE,             /**< Schedule layer*/
  CS_DEBUG_PROCESS,              /**< Process layer*/
  CS_DEBUG_A2L,                  /**< A2L layer*/
  CS_DEBUG_INT,                  /**< Internal layer*/
  CS_DEBUG_ENDMARK               /**< Endmork of array, no real subsystem*/
}cs_debug_sub_t;

#ifdef __cplusplus
extern "C" {
#endif

  /** Set internal debug level
      \retval Active Debuglevel
  */  
  cs_debug_level_t cs_int_debuglevel(
				     cs_debug_level_t level  /**< Debug level*/
				     );

  /** Set internal debugging callback routine
      Default: Function registered which prints debugging to STDOUT
  */
  void cs_int_debug_setcallback(
				void *ctx,                             /**< Callback private data*/
				void (*callb)(void *ctx,
					      cs_debug_sub_t sub,
					      cs_debug_level_t dl,
					      const char *func,
					      const int line,
					      const char *fmt,
					      va_list ap) /**< Callback routine*/
				);
  
  
#ifdef __cplusplus
}
#endif

#endif
