/*  File parser for CAN sniffs
    Copyright (C) 2015 Andreas Stewering-Bone

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>. */

/**
 * @file cs_file_parser.h
 * @author Andreas Stewering-Bone
 * @date 30 June 2015
 * @brief File containing the File parsing API.
 *
 */

#ifndef CS_FILE_PARSER_H
#define CS_FILE_PARSER_H

#include <inttypes.h>
#include <stdio.h>


#define FILE_PARSER_DLC_MAX 8

/** \enum cs_file_parser_dir_t
    Frame direction
*/
typedef enum{
  FILE_PARSER_RX = 0,    /**< Receive*/
  FILE_PARSER_TX         /**< Transmit*/
} cs_file_parser_dir_t;

/** \enum cs_file_parser_type_t
    File type
*/
typedef enum{
  FILE_PARSER_TYPE_UNKNOWN = 0, /**< Unknown type*/
  FILE_PARSER_TYPE_ASC,         /**< ASC-File*/
  FILE_PARSER_TYPE_TRC,         /**< TRC-File*/
  FILE_PARSER_TYPE_LOG          /**< SocketCAN Log file*/
} cs_file_parser_type_t;

/** \struct cs_file_parser_t
    Storage structure
*/
struct cs_file_parser;
typedef struct cs_file_parser cs_file_parser_t;

/** \struct cs_file_parser_entry_t
    One file line
*/
typedef struct{
  double ts;        /**< Timestamp in s*/
  cs_file_parser_dir_t dir; /**< Frame direction*/
  uint32_t canid;   /**< CAN id*/
  int dlc;          /**< DLC*/
  uint8_t data[FILE_PARSER_DLC_MAX]; /**< Frame data*/
}cs_file_parser_entry_t;

#ifdef __cplusplus
extern "C" {
#endif

  /** Init Structure
      \retval not Null Noe failure
      \retval Null Failure
  */
  cs_file_parser_t * cs_file_parser_open(
					 char* filename,                      /**< Filename*/
					 cs_file_parser_type_t ftype          /**< File type*/
					 );

  /**Get one line from file. Next call will get the next line
     \retval 1 Failure, or end of file
     \retval 0 OK
  */ 
  int cs_file_parser_getentry(
			      cs_file_parser_t *data,                 /**< Storage structure*/
			      cs_file_parser_entry_t *entry           /**< Interpreted line*/
			      );

  /** Close structure
      \retval 1 Failure
      \retval 0 OK
  */
  int cs_file_parser_close(
			   cs_file_parser_t *data                     /**< Storage structure*/
			   );

#ifdef __cplusplus
}
#endif

#endif
