/*
    Copyright (C) 2016 Andreas Stewering-Bone

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>. */
/**
 * @file cs_isotp_decoder.h
 * @author Andreas Stewering-Bone
 * @date 25 May 2016
 * @brief ISOTP decoding tools.
 *
 * ISOTP decoding tools for analyzing offline data
 */
#ifndef CS_ISOTP_DECODER_H
#define CS_ISOTP_DECODER_H

#include <inttypes.h>
#include "cs_isotp.h"


struct cs_isotp_decoder;
typedef struct cs_isotp_decoder cs_isotp_decoder_t;

#ifdef __cplusplus
extern "C" {
#endif

  /** Init ISOTP Decoder
      \retval NULL Failure
  */
  /********************************************************************/
  cs_isotp_decoder_t * cs_isotp_decoder_init(
					     uint32_t sa,       /**< SA-CAN-ID*/
					     uint32_t ta,       /**< TA-CAN-ID*/
					     void (*fout)(void *priv_data_out,
							  double ts,
							  uint32_t id,
							  const char *fmt, ...), /**< Print out function callback, May be NULL*/
					     void (*ferror)(void *priv_data_out,
							    double ts,
							    uint32_t id,
							    const char *fmt, ...), /**< Print out error function callback, May be NULL*/
					     void (*fdata)(void *priv_data,
							   double ts,
							   uint32_t id,
							   uint8_t *data,
							   int len,
							   int error), /**< Data function callback, Must not be NULL*/
					     void *priv_data,          /**< Private data handle, for data transmit to high level stacks*/
					     void *priv_data_out       /**< Private data handle for output oriented functions*/
					     );
  /********************************************************************/


  /** Reset ISOTP Decoder states
      \retval 0 success
  */
  /********************************************************************/
  int cs_isotp_decoder_reset(
			     cs_isotp_decoder_t *data      /**< Storage structure*/
			     );
  /********************************************************************/

    /** ISOTP Decoder data in function
      \retval 0 success
  */
  /********************************************************************/
  int cs_isotp_decoder_data(
			    cs_isotp_decoder_t *data,     /**< Storage structure*/
			    double ts,                    /**< Timestamp*/
			    uint32_t id,                  /**< CAN-ID*/
			    uint8_t *bdata,               /**< Data array*/
			    int len                       /**< Data array len*/
			    );
  /********************************************************************/


  /** Close ISOTP Decoder
      \retval 0 success
  */
  /********************************************************************/
  int cs_isotp_decoder_close(
			     cs_isotp_decoder_t *data      /**< Storage structure*/
			     );
  /********************************************************************/
  
#ifdef __cplusplus
}
#endif
  
#endif
