/* 
    Copyright (C) 2013 Andreas Stewering-Bone

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>. */
/**
 * @file cs_uds_defines.h
 * @author Andreas Stewering-Bone
 * @date 9 Oct 2014
 * @brief File containing the UDS specific defines.
 *
 * This file contains the UDS specific defines. 
*/

#ifndef CS_UDS_DEFINES_H
#define CS_UDS_DEFINES_H

/** \def CS_UDS_VERSION_MAJOR
    Major Version of UDS stack
*/
#define CS_UDS_VERSION_MAJOR 0

/** \def CS_UDS_VERSION_MINOR
    Minor Version of UDS stack
*/
#define CS_UDS_VERSION_MINOR 1

/** \def CS_UDS_VERSION
    Get version word from major minor version
*/
#define CS_UDS_VERSION(a, b) (((a) << 8) + (b))

/** \def CS_UDS_VERSION_MAGIC
    UDS interface version word.
 */
#define CS_UDS_VERSION_MAGIC CS_UDS_VERSION(CS_UDS_VERSION_MAJOR, CS_UDS_VERSION_MINOR)

/** \def CS_UDS_CHECKVERSION
    Check UDS stack compatibility
    \retval 0 if stack is compatible
    \retval 1 if stack is incompatible
*/
#define CS_UDS_CHECKVERSION ((CS_UDS_VERSION_MAGIC == cs_uds_getversion())?0:1)

/** \def CS_UDS_SI
    Number of supported Sessions types
*/
#define CS_UDS_SI 6 
/** \def CS_UDS_MAXCYCLIC
    Maximum number of recv retries
*/
#define CS_UDS_MAXCYCLIC 32
/** \def CS_UDS_MAXFUNC
    Maximal allowd functional responses
*/
#define CS_UDS_MAXFUNC 8
/** \def CS_UDS_MAXBYTE
    Maximal allowed data segment in frame
*/
#define CS_UDS_MAXBYTE 2028
/** \def CS_UDS_CANFRAME
    Max bytes in RAW CAN frame
*/
#define CS_UDS_CANFRAME 8

/** \def CS_UDS_MAXDTC
    Array definition size for DTC handling functions
*/
#define CS_UDS_MAXDTC 255

/* some defines, used in server stack*/
#define CS_UDS_FALSE 0
#define CS_UDS_END 0
#define CS_UDS_TRUE 1


/**************************************************/
/*Return defines*/
/**************************************************/
/** \def CS_UDS_ERROR_PR
    Positive Response
*/
#define CS_UDS_ERROR_PR       0x00
/** \def CS_UDS_ERROR_GR
    general reject
*/
#define CS_UDS_ERROR_GR       0x10
/** \def CS_UDS_ERROR_SNS
    Service not supportes
*/
#define CS_UDS_ERROR_SNS      0x11
/** \def CS_UDS_ERROR_SFNS
    Subfunction is not supported
*/
#define CS_UDS_ERROR_SFNS     0x12
/** \def CS_UDS_ERROR_IMLOIF
    incorrectMessageLengthOrInvalidFormat
*/
#define CS_UDS_ERROR_IMLOIF   0x13
/** \def CS_UDS_ERROR_RTL
    Response too long
*/
#define CS_UDS_ERROR_RTL      0x14
/** \def CS_UDS_ERROR_BRR
    Busy repeat request
*/
#define CS_UDS_ERROR_BRR      0x21
/** \def CS_UDS_ERROR_CNC
    conditionsNotCorrect
*/
#define CS_UDS_ERROR_CNC      0x22
/** \def CS_UDS_ERROR_RSE
    Request sequence Error
*/
#define CS_UDS_ERROR_RSE      0x24
/** \def CS_UDS_ERROR_NRFSC 
    noResponseFromSubnetComponent
*/ 
#define CS_UDS_ERROR_NRFSC    0x25
/** \def CS_UDS_ERROR_FPEORA
    FailurePreventsExecutionOfRequestedAction
*/
#define CS_UDS_ERROR_FPEORA   0x26
/** \def CS_UDS_ERROR_ROOR
    Request out of Range
*/
#define CS_UDS_ERROR_ROOR     0x31
/** \def CS_UDS_ERROR_SAD
    securityAccessDenied
*/
#define CS_UDS_ERROR_SAD      0x33
/** \def CS_UDS_ERROR_IK 
    Invalid key
*/
#define CS_UDS_ERROR_IK       0x35
/** \def CS_UDS_ERROR_ENOA
    exceedNumberOfAttempts
*/
#define CS_UDS_ERROR_ENOA     0x36
/** \def CS_UDS_ERROR_RTDNE
    requiredTimeDelayNotExpired
*/
#define CS_UDS_ERROR_RTDNE    0x37
/** \def CS_UDS_ERROR_UDNA
    uploadDownloadNotAccepted
*/
#define CS_UDS_ERROR_UDNA     0x70
/** \def CS_UDS_ERROR_TDS
    transferDataSuspended
*/
#define CS_UDS_ERROR_TDS      0x71
/** \def CS_UDS_ERROR_GPF
    generalProgrammingFailure
*/
#define CS_UDS_ERROR_GPF      0x72
/** \def CS_UDS_ERROR_WBSC
    wrongBlockSequenceCounter
*/
#define CS_UDS_ERROR_WBSC     0x73
/** \def CS_UDS_ERROR_RCRRP
    requestCorrectlyReceived-ResponsePending
*/
#define CS_UDS_ERROR_RCRRP    0x78
/** \def CS_UDS_ERROR_SFNSIAS
    sub-functionNotSupportedInActiveSession
*/
#define CS_UDS_ERROR_SFNSIAS  0x7E
/** \def CS_UDS_ERROR_SNSIAS
    serviceNotSupportedInActiveSession
*/
#define CS_UDS_ERROR_SNSIAS   0x7F
/** \def CS_UDS_ERROR_RPMTH 
    rpmTooHigh
*/
#define CS_UDS_ERROR_RPMTH    0x81
/** \def CS_UDS_ERROR_RPMTL
    rpmTooLow
*/
#define CS_UDS_ERROR_RPMTL    0x82
/** \def CS_UDS_ERROR_EIR
    engineIsRunning
*/
#define CS_UDS_ERROR_EIR      0x83
/** \def CS_UDS_ERROR_EINR
    engineIsNotRunning
*/
#define CS_UDS_ERROR_EINR     0x84
/** \def CS_UDS_ERROR_ERTTL
    engineRunTimeTooLow
*/
#define CS_UDS_ERROR_ERTTL    0x85
/** \def CS_UDS_ERROR_TEMPTH
    temperatureTooHigh
*/
#define CS_UDS_ERROR_TEMPTH   0x86
/** \def CS_UDS_ERROR_TEMPTL
    temperatureTooLow
*/
#define CS_UDS_ERROR_TEMPTL   0x87
/** \def CS_UDS_ERROR_VSTH
    vehicleSpeedTooHigh
*/
#define CS_UDS_ERROR_VSTH     0x88
/** \def  CS_UDS_ERROR_VSTL
    vehicleSpeedTooLow
*/
#define CS_UDS_ERROR_VSTL     0x89
/** \def CS_UDS_ERROR_TPTH
    throttle/PedalTooHigh
*/
#define CS_UDS_ERROR_TPTH     0x8A
/** \def CS_UDS_ERROR_TPTL
    throttle/PedalTooLow
*/
#define CS_UDS_ERROR_TPTL     0x8B
/** \def CS_UDS_ERROR_TRNIN
    transmissionRangeNotInNeutral
*/
#define CS_UDS_ERROR_TRNIN    0x8C
/** \def CS_UDS_ERROR_TRNIG 
    transmissionRangeNotInGear
*/
#define CS_UDS_ERROR_TRNIG    0x8D
/** \def CS_UDS_ERROR_BSNC
    brakeSwitch(es)NotClosed (Brake Pedal not pressed or not applied)
*/
#define CS_UDS_ERROR_BSNC     0x8F
/** \def CS_UDS_ERROR_SLNIP
    shifterLeverNotInPark
*/
#define CS_UDS_ERROR_SLNIP    0x90
/** \def CS_UDS_ERROR_TCCL
    torqueConverterClutchLocked
*/
#define CS_UDS_ERROR_TCCL     0x91
/** \def CS_UDS_ERROR_VTH
    voltageTooHigh
*/
#define CS_UDS_ERROR_VTH      0x92
/** \def CS_UDS_ERROR_VTL 
    voltageTooLow
*/
#define CS_UDS_ERROR_VTL      0x93
/*API defined ERROR, not part of ISO definition*/
/** \def CS_UDS_ERROR_CLIENT_REQDATA
    API: Requested data out of range
*/
#define CS_UDS_ERROR_CLIENT_REQDATA 0x200
/** \def CS_UDS_ERROR_CLIENT_RESPDATA
    API: Response data out of range
*/
#define CS_UDS_ERROR_CLIENT_RESPDATA 0x201
/** \def CS_UDS_ERROR_CLIENT_APICALL
    API call failure
*/
#define CS_UDS_ERROR_CLIENT_APICALL 0x202
/** \def CS_UDS_ERROR_CLIENT_SOCKET
    API: Socket read/write failure
*/
#define  CS_UDS_ERROR_CLIENT_SOCKET 0x203
/** \def CS_UDS_ERROR_CLIENT_SITABLE
    API: SI table entry missing
*/
#define  CS_UDS_ERROR_CLIENT_SITABLE 0x204
/** \def CS_UDS_ERROR_CLIENT_STIMEOUT
    API: Server timeout
*/
#define  CS_UDS_ERROR_CLIENT_STIMEOUT 0x205
/** \def CS_UDS_ERROR_CLIENT_MALLOC
    API: Client malloc
*/
#define  CS_UDS_ERROR_CLIENT_MALLOC 0x206
/** \def CS_UDS_ERROR_CLIENT_IFACE
    API: Client Interface
*/
#define  CS_UDS_ERROR_CLIENT_IFACE 0x207
/** \def CS_UDS_ERROR_CLIENT_BUFFER
    API: Client internal buffer size
*/
#define  CS_UDS_ERROR_CLIENT_BUFFER 0x208
/** \def CS_UDS_ERROR_CLIENT_TXFULL
    API: CAN Send buffer queque is full
*/
#define  CS_UDS_ERROR_CLIENT_TXFULL 0x209
/** \def CS_UDS_ERROR_CLIENT_ISOTP
    API: ISOTP layer error
*/
#define  CS_UDS_ERROR_CLIENT_ISOTP 0x210


/*define default timeouts in ms*/
/** \def CS_UDS_PCANDELTA
    Default PCANDELTA in ms
*/
#define CS_UDS_PCANDELTA  0
/** \def CS_UDS_P2CANSERVER
    Default PCANSERVER
*/
#define CS_UDS_P2CANSERVER 50
/** \def CS_UDS_P2CANSERVERE
    Default PCANSERVERE in ms
*/
#define CS_UDS_P2CANSERVERE 5000
/** \def CS_UDS_P2CANCLIENT
    Default PCANCLIENT in ms
*/
#define CS_UDS_P2CANCLIENT 50
/** \def CS_UDS_P2CANCLIENTE
    Default PCANCLIENTE in ms
*/
#define CS_UDS_P2CANCLIENTE 5000 
/** \def CS_UDS_P2CANCLIENTPHYS
    Default PCANCLIENTPHYS in ms
*/
#define CS_UDS_P3CANCLIENTPHYS 50
/** \def CS_UDS_P2CANCLIENTFUNC
    Default PCANCLIENTFUNC in ms
*/
#define CS_UDS_P3CANCLIENTFUNC 5000 


/*Basic socḱet type definitions*/
/** \def CS_UDS_RX_FUNC
    Functional RX Socket
*/
#define CS_UDS_RX_FUNC 0
/** \def  CS_UDS_TX_SERVER
    TX server socket
*/
#define CS_UDS_TX_SERVER 1
/** \def  CS_UDS_TX_CLIENT
    TX client socket
*/
#define CS_UDS_TX_CLIENT 2
/** \def  CS_UDS_RX_SERVER
    RX server socket
*/
#define CS_UDS_RX_SERVER 1
/** \def  CS_UDS_RX_CLIENT
    RX client socket
*/
#define CS_UDS_RX_CLIENT 2
/** \def CS_UDS_FUNC_ID
    Functional adressing CAN-ID
*/
#define CS_UDS_FUNC_ID 0x7DF

/*Service defines*/
/** \def CS_UDS_SI_RESPOFFSET
    SI Offset for response
*/
#define CS_UDS_SI_RESPOFFSET      0x40
/******************************************/

/******************************************/
/*Diagnostic session control*/
/******************************************/
/** \def CS_UDS_SI_DSC
    SI for session control
*/
#define CS_UDS_SI_DSC         0x10
/** \def CS_UDS_SI_DSC_DS
    Subfunction default session
*/
#define CS_UDS_SI_DSC_DS      0x01
/** \def CS_UDS_SI_DSC_PRGS
    Subfunction ECUProgrammingSession
*/
#define CS_UDS_SI_DSC_PRGS    0x02
/** \def CS_UDS_SI_DSC_EXTDS
    Subfunction ECUExtendedDiagnosticSession
*/
#define CS_UDS_SI_DSC_EXTDS   0x03
/** \def CS_UDS_SI_DSC_SSDS
    Subfunction safetySystemDiagnosticSession
*/
#define CS_UDS_SI_DSC_SSDS    0x04
/** \def CS_UDS_SI_DSC_EOL
    EOLExtendedDiagnosticSession
*/
#define CS_UDS_SI_DSC_EOL     0x40
/** \def CS_UDS_SI_DSC_SUP
    SupplierDiagnosticSession
*/
#define CS_UDS_SI_DSC_SUP     0x60
/******************************************/
/******************************************/
/*ECU reset*/
/******************************************/
/** \def CS_UDS_SI_ER
    SI for ECU reset
*/
#define CS_UDS_SI_ER          0x11
/** \def CS_UDS_SI_ER_HR
    Subfunction Hard reset
*/
#define CS_UDS_SI_ER_HR       0x01
/** \def CS_UDS_SI_ER_KOFFONR
    Subfunction keyOffOnReset
*/
#define CS_UDS_SI_ER_KOFFONR  0x02
/** \def CS_UDS_SI_ER_SR
    Subfunction softReset
*/
#define CS_UDS_SI_ER_SR       0x03
/** \def CS_UDS_SI_ER_ERPSD
    Subfunction enableRapidPowerShutDown
*/
#define CS_UDS_SI_ER_ERPSD    0x04
/** \def CS_UDS_SI_ER_DRPSD
    Subfunction disableRapidPowerShutDown
*/
#define CS_UDS_SI_ER_DRPSD    0x05
/******************************************/
/******************************************/
/*Security access*/
/******************************************/
/** \def CS_UDS_SI_SA
    SI Security access
*/
#define CS_UDS_SI_SA          0x27
/** \def CS_UDS_SI_SA_RSD
    Subfunction request seed
*/
#define CS_UDS_SI_SA_RSD      0x01
/** \def CS_UDS_SI_SA_SK
    Subfunction send key
*/
#define CS_UDS_SI_SA_SK       0x02
/******************************************/
/******************************************/
/*Test present*/
/******************************************/
/** \def CS_UDS_SI_TP
    SI Tester present
*/
#define CS_UDS_SI_TP          0x3E
/******************************************/
/******************************************/
/*Control DTC settings*/
/******************************************/
/** \def CS_UDS_SI_CDTCS
    SI Control DTC settings
*/
#define CS_UDS_SI_CDTCS       0x85
/** \def CS_UDS_SI_CDTCS_ON
    Subfunction Turn on*/
#define CS_UDS_SI_CDTCS_ON    0x01
/** \def CS_UDS_SI_CDTCS_OFF
    Subfunction Turn off
*/
#define CS_UDS_SI_CDTCS_OFF   0x02
/******************************************/
/******************************************/
/*Link control*/
/******************************************/
/** \def CS_UDS_SI_LC
    SI Linkcontrol
*/
#define CS_UDS_SI_LC          0x87
/** \def CS_UDS_SI_LC_VMTWFP
    Subfunction verifyModeTransitionWithFixedParameter
*/
#define CS_UDS_SI_LC_VMTWFP   0x01
/** \def CS_UDS_SI_LC_VMTWSP
    Subfunction verifyModeTransitionWithSpecificParameter
*/
#define CS_UDS_SI_LC_VMTWSP   0x02
/** \def CS_UDS_SI_LC_TM
    Subfunction transitionMode
*/
#define CS_UDS_SI_LC_TM       0x03
/** \def CS_UDS_SI_LC_PC9600
    Parameter PC9600Baud
*/
#define CS_UDS_SI_LC_PC9600   0x01
/** \def CS_UDS_SI_LC_PC19200
    Parameter PC19200Baud
*/
#define CS_UDS_SI_LC_PC19200  0x02
/** \def CS_UDS_SI_LC_PC38400
    Parameter PC38400Baud
*/
#define CS_UDS_SI_LC_PC38400  0x03
/** \def CS_UDS_SI_LC_PC57600
    Parameter PC57600Baud
*/
#define CS_UDS_SI_LC_PC57600  0x04
/** \def CS_UDS_SI_LC_PC38400
    Parameter PC38400Baud
*/
#define CS_UDS_SI_LC_PC38400  0x03
/** \def CS_UDS_SI_LC_CAN125000
    Parameter CAN125000Baud
*/
#define CS_UDS_SI_LC_CAN125000 0x10
/** \def CS_UDS_SI_LC_CAN250000
    Parameter CAN250000Baud
*/
#define CS_UDS_SI_LC_CAN250000 0x11
/** \def CS_UDS_SI_LC_CAN500000
    Parameter CAN500000Baud
*/
#define CS_UDS_SI_LC_CAN500000 0x12
/** \def CS_UDS_SI_LC_CAN1000000
    Parameter CAN1000000Baud
*/
#define CS_UDS_SI_LC_CAN1000000 0x13
/** \def CS_UDS_SI_LC_PROGSU
    Parameter ProgrammingSetup
*/
#define CS_UDS_SI_LC_PROGSU    0x20
/******************************************/
/******************************************/
/*Read Byte by Identifier*/
/******************************************/
/** \def CS_UDS_SI_RDB
    SI Read Data by Identifier
*/
#define CS_UDS_SI_RDB          0x22
/******************************************/
/******************************************/
/*Write Byte by Identifier*/
/******************************************/
/** \def CS_UDS_SI_WDB
    SI Write Data by Identifier
*/
#define CS_UDS_SI_WDB          0x2E
/******************************************/
/******************************************/
/*Routine control*/
/******************************************/
/** \def CS_UDS_SI_RC
    SI Routine Control
*/
#define CS_UDS_SI_RC           0x31
/** \def CS_UDS_SI_RC_STR 
    Subfunction start
*/
#define CS_UDS_SI_RC_STR       0x01
/** \def CS_UDS_SI_RC_STPR
    Subfunction stop
*/
#define CS_UDS_SI_RC_STPR      0x02
/** \def CS_UDS_SI_RC_RRR
    Subfunction request results
*/
#define CS_UDS_SI_RC_RRR       0x03
/******************************************/
/******************************************/
/*Read DTC Information*/
/******************************************/
/** \def CS_UDS_SI_RDTCI
    SI Read DTC Information
*/
#define CS_UDS_SI_RDTCI        0x19
/** \def CS_UDS_SI_RDTCI_RNODTCBSM 
    Subfunction reportNumberOfDTCByStatusMask
*/
#define CS_UDS_SI_RDTCI_RNODTCBSM 0x01
/** \def CS_UDS_SI_RDTCI_RDTCBSM
    Subfunction reportDTCByStatusMask
*/
#define CS_UDS_SI_RDTCI_RDTCBSM 0x02
/** \def CS_UDS_SI_RDTCI_RDTCSSI 
    Subfunction reportDTCSnapshotIdentification
*/
#define CS_UDS_SI_RDTCI_RDTCSSI 0x03
/** \def CS_UDS_SI_RDTCI_RDTCSSBDTC
    Subfunction reportDTCSnapshotRecordByDTCNumber
*/
#define CS_UDS_SI_RDTCI_RDTCSSBDTC 0x04
/** \def CS_UDS_SI_RDTCI_RDTCSDBRN
    Subfunction reportDTCStoredDataByRecordNumber
*/
#define CS_UDS_SI_RDTCI_RDTCSDBRN 0x05
/** \def CS_UDS_SI_RDTCI_RDTCEDRBDN
    Subfunction reportDTCExtDataRecordByDTCNumber
*/
#define CS_UDS_SI_RDTCI_RDTCEDRBDN 0x06
/** \def CS_UDS_SI_RDTCI_RNODTCBSMR
    Subfunction reportNumberOfDTCBySeverityMaskRecord
*/
#define CS_UDS_SI_RDTCI_RNODTCBSMR 0x07
/** \def CS_UDS_SI_RDTCI_RDTCBSMR
    Subfunction reportDTCBySeverityMaskRecord
*/
#define CS_UDS_SI_RDTCI_RDTCBSMR 0x08
/** \def CS_UDS_SI_RDTCI_RSIODTC
    Subfunction reportSeverityInformationOfDTC
*/
#define CS_UDS_SI_RDTCI_RSIODTC 0x09
/** \def CS_UDS_SI_RDTCI_RSUPDTC
    Subfunction reportSupportedDTC
*/
#define CS_UDS_SI_RDTCI_RSUPDTC 0x0A
/** \def CS_UDS_SI_RDTCI_RFTFDTC
    Subfunction reportFirstTestFailedDTC
*/
#define CS_UDS_SI_RDTCI_RFTFDTC 0x0B
/** \def CS_UDS_SI_RDTCI_RFCDTC
    Subfunction reportFirstConfirmedDTC
*/
#define CS_UDS_SI_RDTCI_RFCDTC 0x0C
/** \def CS_UDS_SI_RDTCI_RMRTFDTC
    Subfunction reportMostRecentTestFailedDTC
*/
#define CS_UDS_SI_RDTCI_RMRTFDTC 0x0D
/** \def CS_UDS_SI_RDTCI_RMRCDTC
    Subfunction reportMostRecentConfirmedDTC
*/
#define CS_UDS_SI_RDTCI_RMRCDTC 0x0E
/** \def CS_UDS_SI_RDTCI_RMMDTCBSM 
    Subfunction reportMirrorMemoryDTCByStatusMask
*/
#define CS_UDS_SI_RDTCI_RMMDTCBSM 0x0F
/** \def  CS_UDS_SI_RDTCI_RMMDEDRBDN
    Subfunction reportMirrorMemoryDTCExtDataRecordByDTCNumber
*/
#define CS_UDS_SI_RDTCI_RMMDEDRBDN 0x10
/** \def CS_UDS_SI_RDTCI_RNOMMDTCBSM
    Subfunction reportNumberOfMirrorMemoryDTCByStatusMask
*/
#define CS_UDS_SI_RDTCI_RNOMMDTCBSM 0x11
/** \def CS_UDS_SI_RDTCI_RNOOEOBDDTCBSM
    Subfunction reportNumberOfEmissionsOBDDTCByStatusMask
*/
#define CS_UDS_SI_RDTCI_RNOOEOBDDTCBSM 0x12
/** \def CS_UDS_SI_RDTCI_ROBDDTCBSM
    Subfunction reportEmissionsOBDDTCByStatusMask
*/
#define CS_UDS_SI_RDTCI_ROBDDTCBSM 0x13
/** \def CS_UDS_SI_RDTCI_RDTCFDC
    Subfunction reportDTCFaultDetectionCounter
*/
#define CS_UDS_SI_RDTCI_RDTCFDC 0x14
/** \def CS_UDS_SI_RDTCI_RDTCWPS
    Subfunction reportDTCWithPermanentStatus
*/
#define CS_UDS_SI_RDTCI_RDTCWPS 0x15
/** \def CS_UDS_SI_RDTCI_RDTCEDBR
    Subfunction reportDTCExtDataRecordByRecordNumber
*/
#define CS_UDS_SI_RDTCI_RDTCEDBR 0x16
/** \def CS_UDS_SI_RDTCI_RUDMDTCBSM
    Subfunction reportUserDefMemoryDTCByStatusMask
*/
#define CS_UDS_SI_RDTCI_RUDMDTCBSM 0x17
/** \def CS_UDS_SI_RDTCI_RUDMDTCSSBDTC
    Subfunction reportUserDefMemoryDTCSnapshotRecordByDTCNumber
*/
#define CS_UDS_SI_RDTCI_RUDMDTCSSBDTC 0x18
/** \def CS_UDS_SI_RDTCI_RUDMDTCEDRBDN
    Subfunction reportUserDefMemoryDTCExtDataRecordByDTCNumber
*/
#define CS_UDS_SI_RDTCI_RUDMDTCEDRBDN 0x19
/** \def CS_UDS_SI_RDTCI_RWWHOBDDTCBMR
    Subfunction reportWWHOBDDTCByMaskRecord
*/
#define CS_UDS_SI_RDTCI_RWWHOBDDTCBMR 0x42
/** \def CS_UDS_SI_RDTCI_RWWHOBDDTCWPS 
    Subfunction reportWWHOBDDTCWithPermanentStatus
*/
#define CS_UDS_SI_RDTCI_RWWHOBDDTCWPS 0x55
/******************************************/
/*DTC Status bits masks*/
/******************************************/
/** \def CS_UDS_DTC_STAT_TF
    Bitmask testFailed
*/
#define CS_UDS_DTC_STAT_TF    0x01
/** \def CS_UDS_DTC_STAT_TFTOC
    Bitmask testFailedThisOperationCycle
*/
#define CS_UDS_DTC_STAT_TFTOC 0x02
/** \def CS_UDS_DTC_STAT_PDTC
    Bitmask pendingDTC
*/
#define CS_UDS_DTC_STAT_PDTC  0x04
/** \def CS_UDS_DTC_STAT_CDTC
    Bitmask confirmedDTC
*/
#define CS_UDS_DTC_STAT_CDTC  0x08
/** \def CS_UDS_DTC_STAT_TNCSLC
    Bitmask testNotCompletedSinceLastClear
*/
#define CS_UDS_DTC_STAT_TNCSLC 0x10
/** \def CS_UDS_DTC_STAT_TFSLC
    Bitmask testFailedSinceLastClear
*/
#define CS_UDS_DTC_STAT_TFSLC 0x20
/** \def CS_UDS_DTC_STAT_TNCTOC
    Bitmask testNotCompletedThisOperationCycle
*/
#define CS_UDS_DTC_STAT_TNCTOC 0x40
/** \def CS_UDS_DTC_STAT_WIR
    Bitmask warningIndicatorRequested
*/
#define CS_UDS_DTC_STAT_WIR   0x80
/******************************************/
/*DTC severity bits masks*/
/******************************************/
/** \def CS_UDS_DTC_SEV_MO
    Bitmask maintenanceOnly
*/
#define CS_UDS_DTC_SEV_MO     0x20
/** \def CS_UDS_DTC_SEV_CHKANH
    Bitmask checkAtNextHalt
*/
#define CS_UDS_DTC_SEV_CHKANH 0x40
/** \def CS_UDS_DTC_SEV_CHKI
    Bitmask checkImmediately
*/
#define CS_UDS_DTC_SEV_CHKI   0x80
/******************************************/
/*DTC class bits masks*/
/******************************************/
/** \def CS_UDS_DTC_CLASS_0
    Bitmask DTCClass_0
*/
#define CS_UDS_DTC_CLASS_0    0x01
/** \def CS_UDS_DTC_CLASS_1
    Bitmask DTCClass_1
*/
#define CS_UDS_DTC_CLASS_1    0x02
/** \def CS_UDS_DTC_CLASS_2
    Bitmask DTCClass_2
*/
#define CS_UDS_DTC_CLASS_2    0x04
/** \def CS_UDS_DTC_CLASS_3
    Bitmask DTCClass_3
*/
#define CS_UDS_DTC_CLASS_3    0x08
/** \def CS_UDS_DTC_CLASS_4
    Bitmask DTCClass_4
*/
#define CS_UDS_DTC_CLASS_4    0x10
/******************************************/
/*DTC format identifier*/
/******************************************/
/** \ def CS_UDS_DTC_FORMAT_J2012_DADTCF00
    Format SAE_J2012-DA_DTCFormat_00
*/
#define CS_UDS_DTC_FORMAT_J2012_DADTCF00 0x00
/** \def CS_UDS_DTC_FORMAT_14229_1DTCF
    Format ISO_14229-1_DTCFormat
*/
#define CS_UDS_DTC_FORMAT_14229_1DTCF    0x01
/** \def CS_UDS_DTC_FORMAT_J1939_73DTCF
    SAE_J1939-73_DTCFormat
*/
#define CS_UDS_DTC_FORMAT_J1939_73DTCF   0x02
/** \def CS_UDS_DTC_FORMAT_11992_4DTCF 
    ISO_11992-4_DTCFormat
*/
#define CS_UDS_DTC_FORMAT_11992_4DTCF    0x03
/** \def CS_UDS_DTC_FORMAT_J2012_DADTCF04
    SAE_J2012-DA_DTCFormat_04
*/
#define CS_UDS_DTC_FORMAT_J2012_DADTCF04 0x04
/******************************************/
/******************************************/
/*Clear DTC Information*/
/******************************************/
/** \def CS_UDS_SI_CDTCI
    SI Clear DTC Information
*/ 
#define CS_UDS_SI_CDTCI        0x14
/******************************************/
/******************************************/
/*Request download */
/******************************************/
/** \def CS_UDS_SI_RD
    SI request download
*/ 
#define CS_UDS_SI_RD        0x34
/******************************************/
/******************************************/
/*Request upload */
/******************************************/
/** \def CS_UDS_SI_RU
    SI request upload
*/ 
#define CS_UDS_SI_RU        0x35
/******************************************/
/******************************************/
/*Transfer data */
/******************************************/
/** \def CS_UDS_SI_TD
    SI transfer data
*/ 
#define CS_UDS_SI_TD        0x36
/******************************************/
/******************************************/
/*Request Transfer exit */
/******************************************/
/** \def CS_UDS_SI_RTE
    SI Request transfer exit
*/ 
#define CS_UDS_SI_RTE        0x37
/******************************************/
/******************************************/
/*Request File transfer */
/******************************************/
/** \def CS_UDS_SI_RFT
    SI Request File transfer
*/ 
#define CS_UDS_SI_RFT        0x38


/*DID Defines*/
#define CS_UDS_DID_R 0x01 /*Read*/
#define CS_UDS_DID_W 0x02 /*Write*/
#define CS_UDS_DID_A 0x04 /*Authentification*/
#define CS_UDS_DID_C 0x08 /*Configuration*/
/*Scaling Datatypes (high byte)*/
/*unsigned numeric (1-4Byte)*/
#define CS_UDS_DID_SC_USN      0x0
/*signed numeric (1-4 Byte)*/
#define CS_UDS_DID_SC_SN       0x01
/*bitMappedReportedWithOutMask*/
#define CS_UDS_DID_SC_BMRWOM   0x02
/*bitMappedReportedWithMask*/
#define CS_UDS_DID_SC_BMRWM    0x03
/*BinaryCodedDecimal*/
#define CS_UDS_DID_SC_BCD      0x04
/*stateEncodedVariable (1 byte)*/
#define CS_UDS_DID_SC_SEV      0x05
/*ASCII (1 to 15 bytes for each scalingByte)*/
#define CS_UDS_DID_SC_ASCII    0x06
/*signedFloatingPoint*/
#define CS_UDS_DID_SC_SFP      0x07
/*packet*/
#define CS_UDS_DID_SC_P        0x08
/*formula*/
#define CS_UDS_DID_SC_F        0x09
/*unit/format*/
#define CS_UDS_DID_SC_U        0x0A
/*stateAndConnectionType (1 byte)*/
#define CS_UDS_DID_SC_SACT     0x0B



/*UDS Routine defines*/
#define CS_UDS_R_E 0x01 /*Exec*/
#define CS_UDS_R_A 0x02 /*Auth required*/
#define CS_UDS_R_REQ  0x01 /*Has request data*/
#define CS_UDS_R_INFO 0x02 /*Has info data*/
#define CS_UDS_R_RESP 0x03 /*Has response data*/
#define CS_UDS_R_START 0x01 /*Start*/
#define CS_UDS_R_STOP 0x02 /*Stop*/
#define CS_UDS_R_RES 0x04 /*Result*/


/*UDS DTC defines*/
#define CS_UDS_DTC_EXT_SIZE 4
#define CS_UDS_DTC_EXT_BUF 256
#define CS_UDS_DTC_SNAP_SIZE 4
#define CS_UDS_DTC_SNAP_BUF 256
#define CS_UDS_DTC_E 0x01
#define CS_UDS_DTC_A 0x02
#endif
