/*  XCP CAN Stack for SocketCAN
    Copyright (C) 2013 Andreas Stewering-Bone

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>. */

/**
 * @file cs_xcp_codes.h
 * @author Andreas Stewering-Bone
 * @date 9 Oct 2014
 * @brief File containing several defined for the  XCP API.
 *
 * This file contain several defines for the XCP low level API.
 */

#ifndef CS_XCP_CODES_H
#define CS_XCP_CODES_H

/** \def CS_XCP_VERSION_MAJOR
    Major Version of XCP stack
*/
#define CS_XCP_VERSION_MAJOR 0

/** \def CS_XCP_VERSION_MINOR
    Minor Version of XCP stack
*/
#define CS_XCP_VERSION_MINOR 1

/** \def CS_XCP_VERSION
    Get version word from major minor version
*/
#define CS_XCP_VERSION(a, b) (((a) << 8) + (b))

/** \def CS_XCP_VERSION_MAGIC
    XCP interface version word.
 */
#define CS_XCP_VERSION_MAGIC CS_XCP_VERSION(CS_XCP_VERSION_MAJOR, CS_XCP_VERSION_MINOR)

/** \def CS_XCP_CHECKVERSION
    Check XCP stack compatibility
    \retval 0 if stack is compatible
    \retval 1 if stack is incompatible
*/
#define CS_XCP_CHECKVERSION ((CS_XCP_VERSION_MAGIC == cs_xcp_getversion())?0:1)

/*Table of Event codes (EV)*/
/** \def XCP_EV_RESUME_MODE 
    Slave starting in RESUME mode 
*/
#define XCP_EV_RESUME_MODE 0x00 
/** \def XCP_EV_CLEAR_DAQ
    The DAQ configuration in non-volatile memory has been cleared. 
*/
#define XCP_EV_CLEAR_DAQ 0x01
/** \def XCP_EV_STORE_DAQ
    The DAQ configuration has been stored into non-volatile memory. 
*/
#define XCP_EV_STORE_DAQ 0x02
/** \def XCP_EV_STORE_CAL
    The calibration data has been stored into non-volatile memory. 
*/  
#define XCP_EV_STORE_CAL 0x03
/** \def XCP_EV_CMD_PENDING
    Slave requesting to restart time-out.
*/
#define XCP_EV_CMD_PENDING 0x05
/** \def XCP_EV_DAQ_OVERLOAD
    DAQ processor overload.
*/
#define XCP_EV_DAQ_OVERLOAD 0x06
/** \def XCP_EV_SESSION_TERMINATED
    Session terminated by slave device. 
*/
#define XCP_EV_SESSION_TERMINATED 0x07
/** \def XCP_EV_USER 
    User-defined event 
*/
#define XCP_EV_USER 0xFE
/** \def XCP_EV_TRANSPORT 
    Transport layer specific event 
*/
#define XCP_EV_TRANSPORT 0xFF

/*Table of Service Request codes (SERV)*/
/** \def XCP_SERV_RESET 
    Slave requesting to be reset
*/
#define XCP_SERV_RESET 0x00
/** \def XCP_SERV_TEXT 
    The remaining data bytes of the packet contain plain ASCII
    text. The line separator is LF or CR/LF.
    The text must be null terminated to indicate the end of the
    overall packet.
*/
#define XCP_SERV_TEXT 0x01

/*CMD Codes*/
/** \def XCP_CMD_CONNECT 
    Connect to Slave
*/
#define XCP_CMD_CONNECT 0xFF
/** \def XCP_CMD_DISCONNECT
    Disconnect from slave
*/
#define XCP_CMD_DISCONNECT 0xFE
/** \def XCP_CMD_GET_STATUS 
    Get slave status
*/
#define XCP_CMD_GET_STATUS 0xFD
/** \def XCP_CMD_SYNCH 
    Synch with slave
*/
#define XCP_CMD_SYNCH 0xFC
/** \def XCP_CMD_GET_COMM_MODE_INFO 
    Optional command
*/
#define XCP_CMD_GET_COMM_MODE_INFO 0xFB
/** \def XCP_CMD_GET_ID 
    Optional command
*/
#define XCP_CMD_GET_ID 0xFA
/** \def XCP_CMD_SET_REQUEST 
    Optional command
*/
#define XCP_CMD_SET_REQUEST 0xF9
/** \def XCP_CMD_GET_SEED 
    Optional command
*/
#define XCP_CMD_GET_SEED 0xF8
/** \def XCP_CMD_UNLOCK  
    Optional command
*/
#define XCP_CMD_UNLOCK 0xF7
/** \def XCP_CMD_SET_MTA 
    Optional command
*/
#define XCP_CMD_SET_MTA 0xF6
/** \def XCP_CMD_UPLOAD
    Optional command
*/
#define XCP_CMD_UPLOAD 0xF5
/** \def XCP_CMD_SHORT_UPLOAD 
    Optional command
*/
#define XCP_CMD_SHORT_UPLOAD 0xF4
/** \def XCP_CMD_BUILD_CHECKSUM  
    Optional command
*/
#define XCP_CMD_BUILD_CHECKSUM 0xF3
/** \def XCP_CMD_TRANSPORT_LAYER_CMD 
    Optional transport layer command
*/
#define XCP_CMD_TRANSPORT_LAYER_CMD 0xF2
/** \def XCP_CMD_TRANSPORT_CAN_GET_SLAVE_ID 
    Optional transport layer command: CAN Get slave id
*/
#define XCP_CMD_TRANSPORT_CAN_GET_SLAVE_ID 0xFF
/** \def XCP_CMD_TRANSPORT_CAN_GET_DAQ_ID 
    Optional transport layer command: CAN Get DAQ id
*/
#define XCP_CMD_TRANSPORT_CAN_GET_DAQ_ID 0xFE
/** \def XCP_CMD_USER_CMD
    Optional command
*/
#define XCP_CMD_USER_CMD 0xF1
/** \def XCP_CMD_DOWNLOAD
    Download cmd
*/
#define XCP_CMD_DOWNLOAD 0xF0
/** \def XCP_CMD_DOWNLOAD_NEXT 
    Optional command
*/
#define XCP_CMD_DOWNLOAD_NEXT 0xEF
/** \def XCP_CMD_DOWNLOAD_MAX 
    Optional command
*/
#define XCP_CMD_DOWNLOAD_MAX 0xEE
/** \def XCP_CMD_SHORT_DOWNLOAD
    Optional command
*/
#define XCP_CMD_SHORT_DOWNLOAD 0xED
/** \def XCP_CMD_MODIFY_BITS 
    Optional command
*/
#define XCP_CMD_MODIFY_BITS 0xEC
/** \def XCP_CMD_SET_CAL_PAGE 
    Select calibration page
*/
#define XCP_CMD_SET_CAL_PAGE 0xEB
/** \def XCP_CMD_GET_CAL_PAGE 
    Get Calibration page
*/
#define XCP_CMD_GET_CAL_PAGE 0xEA
/** \def XCP_CMD_GET_PAG_PROCESSOR_INFO 
    Optional command
*/
#define XCP_CMD_GET_PAG_PROCESSOR_INFO 0xE9
/** \def XCP_CMD_GET_SEGMENT_INFO 
    Optional command
*/
#define XCP_CMD_GET_SEGMENT_INFO 0xE8
/** \def XCP_CMD_GET_PAGE_INFO 
    Optional command
*/
#define XCP_CMD_GET_PAGE_INFO 0xE7
/** \def XCP_CMD_SET_SEGMENT_MODE 
    Optional command
*/
#define XCP_CMD_SET_SEGMENT_MODE 0xE6
/** \def XCP_CMD_GET_SEGMENT_MODE 
    Optional command
*/
#define XCP_CMD_GET_SEGMENT_MODE 0xE5
/** \def XCP_CMD_COPY_CAL_PAGE 
    Optional command
*/
#define XCP_CMD_COPY_CAL_PAGE 0xE4
/** \def XCP_CMD_CLEAR_DAQ_LIST 
    Clear DAQ list
*/
#define XCP_CMD_CLEAR_DAQ_LIST 0xE3
/** \def XCP_CMD_SET_DAQ_PTR
    Set DAQ pointer
*/
#define XCP_CMD_SET_DAQ_PTR 0xE2
/** \def XCP_CMD_WRITE_DAQ
    Write DAQ list
*/
#define XCP_CMD_WRITE_DAQ 0xE1
/** \def XCP_CMD_SET_DAQ_LIST_MODE
    Set DAQ list mode
*/
#define XCP_CMD_SET_DAQ_LIST_MODE 0xE0
/** \def XCP_CMD_GET_DAQ_LIST_MODE
    Get DAQ list mode
*/
#define XCP_CMD_GET_DAQ_LIST_MODE 0xDF
/** \def XCP_CMD_START_STOP_DAQ_LIST
    Start/Stop transmit DAQ list
*/
#define XCP_CMD_START_STOP_DAQ_LIST 0xDE
/** \def XCP_CMD_START_STOP_SYNCH
    Start/Stop DAQ list sync
*/
#define XCP_CMD_START_STOP_SYNCH 0xDD
/** \def XCP_CMD_GET_DAQ_CLOCK
    Optional command
*/
#define XCP_CMD_GET_DAQ_CLOCK 0xDC
/** \def XCP_CMD_READ_DAQ
    Optional command
*/
#define XCP_CMD_READ_DAQ 0xDB
/** \def XCP_CMD_GET_DAQ_PROCESSOR_INFO
    Optional command
*/
#define XCP_CMD_GET_DAQ_PROCESSOR_INFO 0xDA
/** \def XCP_CMD_GET_DAQ_RESOLUTION_INFO
    Optional command
*/
#define XCP_CMD_GET_DAQ_RESOLUTION_INFO 0xD9
/** \def XCP_CMD_GET_DAQ_LIST_INFO
    Optional command
*/
#define XCP_CMD_GET_DAQ_LIST_INFO 0xD8
/** \def XCP_CMD_GET_DAQ_EVENT_INFO
    Optional command
*/
#define XCP_CMD_GET_DAQ_EVENT_INFO 0xD7
/** \def XCP_CMD_FREE_DAQ
    Optional command
*/
#define XCP_CMD_FREE_DAQ 0xD6
/** \def XCP_CMD_ALLOC_DAQ
    Optional command
*/
#define XCP_CMD_ALLOC_DAQ 0xD5
/** \def XCP_CMD_ALLOC_ODT
    Optional command
*/
#define XCP_CMD_ALLOC_ODT 0xD4
/** \def XCP_CMD_ALLOC_ODT_ENTRY
    Optional command
*/
#define XCP_CMD_ALLOC_ODT_ENTRY 0xD3
/** \def XCP_CMD_PROGRAM_START
    Program start
*/
#define XCP_CMD_PROGRAM_START 0xD2
/** \def XCP_CMD_PROGRAM_CLEAR
    Program clear
*/
#define XCP_CMD_PROGRAM_CLEAR 0xD1
/** \def XCP_CMD_PROGRAM
    Program
*/
#define XCP_CMD_PROGRAM 0xD0
/** \def XCP_CMD_PROGRAM_RESET
    Optional command
*/
#define XCP_CMD_PROGRAM_RESET 0xCF
/** \def XCP_CMD_GET_PGM_PROCESSOR_INFO
    Optional command
*/
#define XCP_CMD_GET_PGM_PROCESSOR_INFO 0xCE
/** \def XCP_CMD_GET_SECTOR_INFO
    Optional command
*/
#define XCP_CMD_GET_SECTOR_INFO 0xCD
/** \def XCP_CMD_PROGRAM_PREPARE
    Optional command
*/
#define XCP_CMD_PROGRAM_PREPARE 0xCC
/** \def XCP_CMD_PROGRAM_FORMAT
    Optional command
*/
#define XCP_CMD_PROGRAM_FORMAT 0xCB
/** \def XCP_CMD_PROGRAM_NEXT
    Optional command
*/
#define XCP_CMD_PROGRAM_NEXT 0xCA
/** \def XCP_CMD_PROGRAM_MAX
    Optional command
*/
#define XCP_CMD_PROGRAM_MAX 0xC9
/** \def XCP_CMD_PROGRAM_VERIFY
    Optional command
*/
#define XCP_CMD_PROGRAM_VERIFY 0xC8

/** \def XCP_BM_CALPAG
    Bitmask for CALPAG feature
*/
#define XCP_BM_CALPAG 0x01
/** \def XCP_BM_DAQ
    Bitmask for DAQ feature
*/
#define XCP_BM_DAQ 0x04
/** \def XCP_BM_STIM
    Bitmask for STIM feature
*/
#define XCP_BM_STIM 0x08
/** \def XCP_BM_PGM
    Bitmask for PGM feature
*/
#define XCP_BM_PGM 0x10
/** \def XCP_BM_BYTE_ORDER
    Bitmask for Byte order
*/
#define XCP_BM_BYTE_ORDER 0x01
/** \def XCP_BM_ADDRESS_GRANULARITY_LOW
    Bitmask for Address granularity (Low Bit)
*/
#define XCP_BM_ADDRESS_GRANULARITY_LOW 0x02
/** \def XCP_BM_ADDRESS_GRANULARITY_HIGH
    Bitmask for Address granularity (High Bit)
*/
#define XCP_BM_ADDRESS_GRANULARITY_HIGH 0x04
/** \def XCP_BM_SLAVE_BLOCK_MODE
    Bitmask for Slave block mode
*/
#define XCP_BM_SLAVE_BLOCK_MODE 0x40
/** \def XCP_BM_OPTIONAL
    Bitmask for Optional flag
*/
#define XCP_BM_OPTIONAL 0x80

/** \def XCP_BM_STATUS_STORE_CALPAG
    Bitmask for Status store CALPAG
*/
#define XCP_BM_STATUS_STORE_CALPAG 0x01
/** \def XCP_BM_STATUS_STORE_DAQ
    Bitmask for Status store DAQ
*/
#define XCP_BM_STATUS_STORE_DAQ 0x04
/** \def XCP_BM_STATUS_CLEAR_DAQ
    Bitmask for Status clear DAQ
*/
#define XCP_BM_STATUS_CLEAR_DAQ 0x08
/** \def XCP_BM_STATUS_DAQ_RUNNING
    Bitmask for Status DAQ running
*/
#define XCP_BM_STATUS_DAQ_RUNNING 0x40
/** \def XCP_BM_STATUS_RESUME
    Bitmask for Status Resume
*/
#define XCP_BM_STATUS_RESUME 0x80
/** \def XCP_BM_PROT_CALPAG
    Bitmask for Protection status CALPAG
*/
#define XCP_BM_PROT_CALPAG 0x01
/** \def XCP_BM_PROT_DAQ
    Bitmask for Protection status DAQ
*/
#define XCP_BM_PROT_DAQ 0x04
/** \def XCP_BM_PROT_STIM
    Bitmask for Protection status STIM
*/
#define XCP_BM_PROT_STIM 0x08
/** \def XCP_BM_PROT_PGM
    Bitmask for Protection status PGM
*/
#define XCP_BM_PROT_PGM 0x10
/** \def XCP_BM_COMMODE_IBM
    Bitmask for Interleaved block mode
*/
#define XCP_BM_COMMODE_IBM 0x02
/** \def XCP_BM_COMMODE_MBM
    Bitmask for master block mode
*/
#define XCP_BM_COMMODE_MBM 0x01
/** \def XCP_BM_DAQ_PROP_CONFIG
    Bitmask for DAQ Config support
*/
#define XCP_BM_DAQ_PROP_CONFIG 0x01
/** \def XCP_BM_DAQ_PROP_PRESCALER
    Bitmask for DAQ PRESCALER support
*/
#define XCP_BM_DAQ_PROP_PRESCALER 0x02
/** \def XCP_BM_DAQ_PROP_RESUME
    Bitmask for DAQ Resume support
*/
#define XCP_BM_DAQ_PROP_RESUME 0x04
/** \def XCP_BM_DAQ_PROP_BIT_STIM
    Bitmask for DAQ Bit STIM support
*/
#define XCP_BM_DAQ_PROP_BIT_STIM 0x08
/** \def XCP_BM_DAQ_PROP_TIMESTAMP
    Bitmask for DAQ Timestamp support
*/
#define XCP_BM_DAQ_PROP_TIMESTAMP 0x10
/** \def XCP_BM_DAQ_PROP_PID_OFF
    Bitmask for DAQ PID off support
*/
#define XCP_BM_DAQ_PROP_PID_OFF 0x20
/** \def XCP_BM_DAQ_PROP_OVERLOAD
    Bitmask for DAQ Overload type
*/
#define XCP_BM_DAQ_PROP_OVERLOAD 0xC0
/** \def XCP_BM_DAQ_KEY_OPT
    Bitmask for DAQ Optimisation type
*/
#define XCP_BM_DAQ_KEY_OPT 0x0F
/** \def XCP_BM_DAQ_KEY_ADDR_EXT
    Bitmask for DAQ Address extension type
*/
#define XCP_BM_DAQ_KEY_ADDR_EXT 0x30
/** \def XCP_BM_DAQ_KEY_IDENT
    Bitmask for DAQ Identification type
*/
#define XCP_BM_DAQ_KEY_IDENT 0xC0
/** \def XCP_BM_TS_SIZE
    Bitmask for Timestamp size
*/
#define XCP_BM_TS_SIZE 0x07
/** \def XCP_BM_TS_FIXED
    Bitmask for Timestamp fixed
*/
#define XCP_BM_TS_FIXED 0x08
/** \def XCP_BM_TS_UNIT
    Bitmask for Timestamp unit
*/
#define XCP_BM_TS_UNIT 0xF0

/** \def XCP_SEVERITY_S0
    Severity level Information
*/
#define XCP_SEVERITY_S0 0x00
/** \def XCP_SEVERITY_S1
    Severity level Warning
*/
#define XCP_SEVERITY_S1 0x10
/** \def XCP_SEVERITY_S2
    Severity level Error
*/
#define XCP_SEVERITY_S2 0x20
/** \def XCP_SEVERITY_S3
    Severity level Fatal error
*/
#define XCP_SEVERITY_S3 0x30
/** \def XCP_OVERFLOW_IDENT_MAXODT
    Maximum ODT number if overflow indecation via 
    MSB Bit in ODT number
*/
#define XCP_OVERFLOW_IDENT_MAXODT 0x7F

/** \def XCP_ERROR_CMD_SYNCH
    XCP Protocol Error: Command processor synchronization
*/
#define XCP_ERROR_CMD_SYNCH 0x00
/** \def XCP_ERROR_CMD_BUSY
    XCP Protocol Error: Command was not executed
*/
#define XCP_ERROR_CMD_BUSY 0x10
/** \def XCP_ERROR_DAQ_ACTIVE
    XCP Protocol Error: Command rejected because DAQ is
running.
*/
#define XCP_ERROR_DAQ_ACTIVE 0x11
/** \def XCP_ERROR_PGM_ACTIVE
    XCP Protocol Error: Command rejected because PGM is
running.
*/
#define XCP_ERROR_PGM_ACTIVE 0x12
/** \def XCP_ERROR_CMD_UNKNOWN
    XCP Protocol Error: Unknown command or not implemented
optional command
*/
#define XCP_ERROR_CMD_UNKNOWN 0x20
/** \def XCP_ERR_CMD_SYNTAX
    XCP Protocol Error: Command syntax invalid
*/
#define XCP_ERROR_CMD_SYNTAX 0x21
/** \def XCP_ERROR_OUT_OF_RANGE
    XCP Protocol Error: Command syntax valid but command
parameter(s) out of range
*/
#define XCP_ERROR_OUT_OF_RANGE 0x22
/** \def XCP_ERROR_WRITE_PROTECTED
    XCP Protocol Error: The memory location is write protected
*/
#define XCP_ERROR_WRITE_PROTECTED 0x23
/** \def XCP_ERROR_ACCESS_DENIED
    XCP Protocol Error: The memory location is not accessible
*/
#define XCP_ERROR_ACCESS_DENIED 0x24
/** \def XCP_ERROR_ACCESS_LOCKED
    XCP Protocol Error: Access denied,
    Seed & Key is required 
*/
#define XCP_ERROR_ACCESS_LOCKED 0x25
/** \def XCP_ERROR_PAGE_NOT_VALID
    XCP Protocol Error: Selected page not available
*/
#define XCP_ERROR_PAGE_NOT_VALID 0x26
/** \def XCP_ERROR_MODE_NOT_VALID
    XCP Protocol Error: Selected page mode not available
*/
#define XCP_ERROR_MODE_NOT_VALID 0x27
/** \def XCP_ERROR_SEGMENT_NOT_VALID
    XCP Protocol Error: Selected segment not valid
*/
#define XCP_ERROR_SEGMENT_NOT_VALID 0x28
/** \def XCP_ERROR_SEQUENCE
    XCP Protocol Error: Sequence error
*/
#define XCP_ERROR_SEQUENCE 0x29
/** \def XCP_ERROR_DAQ_CONFIG
    XCP Protocol Error: DAQ configuration not valid 
*/
#define XCP_ERROR_DAQ_CONFIG 0x2A
/** \def XCP_ERROR_MEMORY_OVERFLOW
    XCP Protocol Error: Memory overflow error
*/
#define XCP_ERROR_MEMORY_OVERFLOW 0x30
/** \def XCP_ERROR_GENERIC
    XCP Protocol Error: Generic error.
*/
#define XCP_ERROR_GENERIC 0x31
/** \def XCP_ERROR_VERIFY
    XCP Protocol Error: The slave internal program verify routine
    detects an error.
*/
#define XCP_ERROR_VERIFY 0x32
/** \def XCP_ERROR_NOERROR
    XCP API Error: No Error
*/
#define XCP_ERROR_NOERROR 0x100

/** \def XCP_ERROR_ERROR
    XCP API Error: General unspecific error
*/
#define XCP_ERROR_ERROR 0x101
/** \def XCP_ERROR_INTERFACE
    XCP API Error: General unspecific error
*/
#define XCP_ERROR_INTERFACE 0x102
/** \def XCP_ERROR_API
    XCP API Error: API call failiure
*/
#define XCP_ERROR_API 0x103
/** \def XCP_ERROR_MALLOC
    XCP API Error: Malloc failure
*/
#define XCP_ERROR_MALLOC 0x104
/** \def XCP_ERROR_SEND
    XCP API Error: Send failure
*/
#define XCP_ERROR_SEND 0x105
/** \def XCP_ERROR_RECV
    XCP API Error: Recieve failure
*/
#define XCP_ERROR_RECV 0x106
/** \def XCP_ERROR_UNSUPPORTED
    XCP API Error: Unsupported feature
*/
#define XCP_ERROR_UNSUPPORTED 0x107
/** \def XCP_ERROR_BUFFER
    XCP API Error: Buffer overrange
*/
#define XCP_ERROR_BUFFER 0x108
/** \def XCP_ERROR_UNEXPECTED
    XCP API Error: Received unexpected data
*/
#define XCP_ERROR_UNEXPECTED 0x109
/** \def XCP_ERROR_TIMEOUT
    XCP API Error: General timeout error
*/
#define XCP_ERROR_TIMEOUT 0x10A
/** \def XCP_ERROR_TIMEOUTT1
    XCP API Error: Timeout T1 error
*/
#define XCP_ERROR_TIMEOUTT1 0x10B
/** \def XCP_ERROR_TIMEOUTT6
    XCP API Error: Timeout T6 error
*/
#define XCP_ERROR_TIMEOUTT6 0x10C
/** \def XCP_ERROR_CTO
    XCP API Error: Package request greater than max_cto
*/
#define XCP_ERROR_CTO 0x10D
/** \def XCP_ERROR_ALLOC
    XCP API Error: Invalid alloc request
*/
#define XCP_ERROR_ALLOC 0x10E
/** \def XCP_ERROR_DAQ
    XCP API Error: Invalid DAQ request
*/
#define XCP_ERROR_DAQ 0x10F
/** \def XCP_ERROR_SLAVE_UNSUPPORTED
    XCP API Error: Function is not supported by Slave
*/
#define XCP_ERROR_SLAVE_UNSUPPORTED 0x200
/** \def XCP_ERROR_DAQ_RANGE
    XCP API Error: Invalid DAQ index request
*/
#define XCP_ERROR_DAQ_RANGE 0x201
/** \def XCP_ERROR_EV_RANGE
    XCP API Error: Invalid Event channel index request
*/
#define XCP_ERROR_EV_RANGE 0x202
/** \def XCP_ERROR_DAQ_PTR
    XCP API Error: Invalid DAQ pointer request
*/
#define XCP_ERROR_DAQ_PTR 0x203
/** \def XCP_ERROR_ODT_RANGE
    XCP API Error: Invalid ODT index request
*/
#define XCP_ERROR_ODT_RANGE 0x204
/** \def XCP_ERROR_DAQ_SEQUENCE
    XCP API Error: Invalid DAQ list data structure command
*/
#define XCP_ERROR_DAQ_SEQUENCE 0x205
/** \def XCP_ERROR_ODT_UKNOWN
    XCP API Error: Received an unknown ODT pid
*/
#define XCP_ERROR_ODT_UNKNOWN 0x206
/** \def XCP_ERROR_ODT_SIZE
    XCP API Error: Received an ODT with invalid size
*/
#define XCP_ERROR_ODT_SIZE 0x207
/** \def XCP_ERROR_DAQ_PROCESS
    XCP API Error: Failure in DAQ processing
*/
#define XCP_ERROR_DAQ_PROCESS 0x208
/** \def XCP_ERROR_ENTRY_RANGE
    XCP API Error: Entry index out of range
*/
#define XCP_ERROR_ENTRY_RANGE 0x209
/** \def XCP_ERROR_BUFFER_RANGE
    XCP API Error: Buffer index out of range
*/
#define XCP_ERROR_BUFFER_RANGE 0x20A
/** \def XCP_ERROR_API_VERSION
    XCP API Error: ASAP version not supported
*/
#define XCP_ERROR_API_VERSION 0x20B
/** \def XCP_ERROR_API_PARSE
    XCP API Error: A2L parsing error
*/
#define XCP_ERROR_API_PARSE 0x20C
/** \def XCP_ERROR_API_FILE
    XCP API Error: Cannot open file
*/
#define XCP_ERROR_API_FILE 0x20D
/** \def XCP_ERROR_API_PARAM
    XCP API Error: Parameter argument is wrong
*/
#define XCP_ERROR_API_PARAM 0x20E
/** \def XCP_ERROR_API_SIGNALRANGE
    XCP API Error: Too many signals configured
*/
#define XCP_ERROR_API_SIGNALRANGE 0x20F

#endif
